@@ -179,8 +179,6 @@ if tx_period_tolerance < 0 or tx_period_tolerance > 100:
 	log_warn("Config parameter 'CAN_tx_period_tolerance' wrong value '%s'. Assumed 100 (\%)." \
 		% str(CAN_tx_period_tolerance))
 
-print("Task: ",tx_proc_task , " Tol: ",tx_period_tolerance )
-
 macro_prefix = "kCAN_" + net_name_str + "msgTxPeriod_"
 macro_names = []
 macro_values = []
@@ -197,8 +195,6 @@ for message in network.messages.values():
 		upper_tol_perc = (100 + tx_period_tolerance) / 100
 		lower_tol_perc = (100 - tx_period_tolerance) / 100
 
-		print("Period: ",message_period, " Up Tol: ",upper_tol_perc," Down Tol: ",lower_tol_perc )
-
 		if ((perioc_in_ticks * tx_proc_task) > (upper_tol_perc * message_period)) or \
 		((perioc_in_ticks * tx_proc_task) < (lower_tol_perc * message_period)):
 			log_warn(("Generated period of '%sms' for message '%s' doesn't met tolerance of +/-'%s' percent. " \
@@ -224,12 +220,12 @@ for i, macro_name in enumerate(macro_names):
 tx_data_init_val = network.get_simple_param("CAN_tx_data_init_val")
 tx_data_init_val = cg.to_hex_string_with_suffix(tx_data_init_val)
 macro_name = "kCAN_" + net_name_str + "TxDataInitVal"
-cog.outl("#define "+macro_name+"()\t\t("+tx_data_init_val+")")
+cog.outl("#define "+macro_name+"\t\t("+tx_data_init_val+")")
 
 rx_data_init_val = network.get_simple_param("CAN_rx_data_init_val")
 rx_data_init_val = cg.to_hex_string_with_suffix(rx_data_init_val)
 macro_name = "kCAN_" + net_name_str + "RxDataInitVal"
-cog.outl("#define "+macro_name+"()\t\t("+rx_data_init_val+")\n")
+cog.outl("#define "+macro_name+"\t\t("+rx_data_init_val+")\n")
 ]]] */
 // [[[end]]]
 
